@@ -3,11 +3,18 @@
 import os
 import numpy as np
 import pytest
+import sys
 
 from qa4sm_reader.img import QA4SMImg
 from qa4sm_reader import globals
 
 
+# if sys.platform.startswith("win"):
+#     pytestmark = pytest.mark.skip(
+#         "Failing on Windows."
+#     )
+
+
 @pytest.fixture
 def testfile_path():
     testfile = '3-ERA5_LAND.swvl1_with_1-C3S.sm_with_2-SMOS.Soil_Moisture.nc'
